@@ -17,9 +17,9 @@ https://www.themoviedb.org/documentation/api/status-codes
 """
 
 __title__ = 'tmdbsimple'
-__version__ = '1.4.0'
+__version__ = '1.4.1'
 __author__ = 'Celia Oakley'
-__copyright__ = 'Copyright (c) 2013-1016 Celia Oakley'
+__copyright__ = 'Copyright (c) 2013-1017 Celia Oakley'
 __license__ = 'GPLv3'
 
 import os
@@ -36,12 +36,6 @@ from .people import People, Credits, Jobs
 from .search import Search
 from .tv import TV, TV_Seasons, TV_Episodes, Networks
 
-def _get_env_key(key):
-    try:
-        return os.environ[key]
-    except KeyError:
-        return None
 
-API_KEY = _get_env_key('TMDB_API_KEY')
+API_KEY = os.environ.get('TMDB_API_KEY', None)
 API_VERSION = '3'
-
